@@ -22,6 +22,9 @@ BASE_URL = "https://api.neogrid.dk/public/api/v1"
 MAX_CIDS_PER_REQ = 3
 MAX_POINTS_PER_REQ = 90000
 
+GET_TIMEOUT_SECONDS = 60
+PUT_TIMEOUT_SECONDS = 10
+
 # Perhaps we can steal this from the OS?
 TIMEZONE = gettz("Europe/Copenhagen")
 DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
@@ -210,23 +213,39 @@ class ApiSession(metaclass=Singleton):
         payload = payload if payload is not None else {}
         headers = headers if headers is not None else {}
 
-        Logging().info(f"GET /{endpoint} [{self.addr()}]")
+        Logging().debug(f"GET /{endpoint} [{self.addr()}]")
+        # Logging().debug(f"{payload}")
 
         path = f"{self.base_url}/{endpoint}"
 
         if out == "csv":
             headers["Accept"] = "text/csv"
-        resp = self.session.get(path, params=payload, headers=headers)
-        resp.raise_for_status()
+        resp = self.session.get(
+            path, params=payload, headers=headers, timeout=GET_TIMEOUT_SECONDS
+        )
+
+        Logging().debug(f"{resp.status_code} {resp.reason}")
+        try:
+            resp.raise_for_status()
+        except Exception as e:
+            msg = """GET - FAILED
+            URL: {}
+            Payload: {}
+            """.format(
+                path, str(payload)
+            )
+            Logging().error(msg, exception=e)
+            raise e
 
         try:
             if out == "json":
                 return resp.json()
             elif out == "csv":
+                # Logging().debug(f"{resp.text}")
                 data = StringIO(resp.text)
                 return pd.read_csv(data, delimiter=";")
-        except:
-            raise APIDataExtractError()
+        except Exception as e:
+            raise APIDataExtractError() from e
 
     def api_put(self, endpoint, json_payload=None) -> Response:
         """
@@ -243,8 +262,18 @@ class ApiSession(metaclass=Singleton):
         Logging().info(f"PUT /{endpoint} [{self.addr()}]")
 
         path = f"{self.base_url}/{endpoint}"
-        r = self.session.put(path, json=json_payload)
-        r.raise_for_status()
+        r = self.session.put(path, json=json_payload, timeout=PUT_TIMEOUT_SECONDS)
+        try:
+            r.raise_for_status()
+        except Exception as e:
+            msg = """PUT - FAILED
+            URL: {}
+            Payload: {}
+            """.format(
+                path, str(json_payload)
+            )
+            Logging().error(msg, exception=e)
+            raise e
         return r
 
     def _load_api_key(self, existing):
@@ -331,10 +360,10 @@ def set_api_key(api_key: str) -> None:
     if api_key is None:
         if "PREHEAT_API_KEY_OVERRIDE" in os.environ:
             os.environ.pop("PREHEAT_API_KEY_OVERRIDE")
-            Logging().debug("API key override unset")
+            Logging().info("API key override unset")
     else:
         os.environ["PREHEAT_API_KEY_OVERRIDE"] = api_key
-        Logging().debug("API key override set")
+        Logging().info("API key override set")
     ApiSession().set_api_key()
 
 
