@@ -1,13 +1,23 @@
+"""
+This module defines the Building class, which represents buildings containing different units and their data
+"""
 import re
+from datetime import datetime
 from typing import Dict, List, Optional, Union
 
 import pandas as pd
 
 from . import unit_graph
 from .api import AccessDeniedError, api_get
-from .building_unit import BaseBuildingUnit, populate_units
-from .data import load_model_data, pd
+from .backwards_compatibility import load_parameter_old_naming
+from .building_unit import (
+    BaseBuildingUnit,
+    exclude_shared_units_from_list,
+    populate_units,
+)
+from .data import load_model_data
 from .helpers import convenience_result_list_shortener, sanitise_datetime_input
+from .logging import Logging
 from .price import SupplyPoint
 from .weather import Weather
 from .zone import Zone, populate_zones
@@ -62,81 +72,84 @@ class Building(object):
 
     def load_data(
         self,
-        start_date,
-        end_date,
-        time_resolution="hour",
-        components: Optional[Dict] = {},
+        start: Union[str, datetime],
+        end: Union[str, datetime],
+        resolution: str = "hour",
+        components: Optional[Dict] = None,
+        **kwargs,
     ) -> None:
         """
 
-        :param start_date:
-        :type start_date:
-        :param end_date:
-        :type end_date:
-        :param time_resolution:
-        :type time_resolution:
+        :param start:
+        :type start:
+        :param end:
+        :type end:
+        :param resolution:
+        :type resolution:
         :param components:
         :type components:
         :return:
         :rtype:
         """
-        start_date = sanitise_datetime_input(start_date)
-        end_date = sanitise_datetime_input(end_date)
+
+        if components is None:
+            components = {}
+
+        start, end, resolution = load_parameter_old_naming(
+            start, end, resolution, **kwargs
+        )
+
+        start = sanitise_datetime_input(start)
+        end = sanitise_datetime_input(end)
         if components is None:
             components = {}
 
         if len(components) == 0:
             # Load all data on building, if nothing is specified
-            self.weather.load_data(
-                start_date, end_date, time_resolution, components.get("weather")
-            )
+            self.weather.load_data(start, end, resolution, components.get("weather"))
             for node, data in self.G.nodes.data():
                 u_i = data["unit"]
                 c_i = components.get(u_i.unit_type)
-                u_i.load_data(start_date, end_date, time_resolution, components=c_i)
+                u_i.load_data(start, end, resolution, components=c_i)
 
         else:
             # Otherwise, just load specific components
             for i in components.keys():
                 c_i = components.get(i)
                 if i == "weather":
-                    self.weather.load_data(
-                        start_date, end_date, time_resolution, components=c_i
-                    )
+                    self.weather.load_data(start, end, resolution, components=c_i)
                 else:
                     for u_i in self.query_units(unit_type=i):
-                        u_i.load_data(
-                            start_date, end_date, time_resolution, components=c_i
-                        )
+                        u_i.load_data(start, end, resolution, components=c_i)
 
     def load_dataset(
         self,
         component_map,
-        start_date,
-        end_date,
-        time_resolution="hour",
-        load_weather=True,
-    ):
+        start,
+        end,
+        resolution: str = "hour",
+        load_weather: bool = True,
+    ) -> pd.DataFrame:
         """
 
         :param component_map:
         :type component_map:
-        :param start_date:
-        :type start_date:
-        :param end_date:
-        :type end_date:
-        :param time_resolution:
-        :type time_resolution:
+        :param start:
+        :type start:
+        :param end:
+        :type end:
+        :param resolution:
+        :type resolution:
         :param load_weather:
         :type load_weather:
         :return:
         :rtype:
         """
 
-        df = load_model_data(component_map, start_date, end_date, time_resolution)
+        df = load_model_data(component_map, start, end, resolution)
 
         if load_weather is True:
-            self.weather.load_data(start_date, end_date, time_resolution)
+            self.weather.load_data(start, end, resolution)
             df_weather = self.weather.data
             df_weather.columns = "weather." + df_weather.columns
             df = pd.concat((df_weather, df), axis=1)
@@ -179,7 +192,11 @@ class Building(object):
         return all_comps
 
     def query_units(
-        self, unit_type: str = None, name: str = None, unit_id: int = None
+        self,
+        unit_type: str = None,
+        name: str = None,
+        unit_id: int = None,
+        exclude_shared: bool = False,
     ) -> List[BaseBuildingUnit]:
         """
 
@@ -189,61 +206,69 @@ class Building(object):
         :type name:
         :param unit_id:
         :type unit_id:
+        :param exclude_shared: if True, excludes shared units
+        :type exclude_shared:
         :return:
         :rtype:
         """
         # If we pass a unit ID, find specific unit
         if unit_id:
             if unit_id in self.G.nodes.keys():
-                return [self.G.nodes[unit_id]["unit"]]
+                out = [self.G.nodes[unit_id]["unit"]]
             else:
-                return []
+                out = []
 
-        # If we pass a unit_type, check if we do regex search or strict search
-        if unit_type:
-            if unit_type[0] == "?":
-                r_type = re.compile(unit_type[1:])
-                type_match = lambda t: r_type.search(t)
-            else:
-                type_match = lambda t: t == unit_type
+        else:
+            # If we pass a unit_type, check if we do regex search or strict search
+            if unit_type:
+                if unit_type[0] == "?":
+                    r_type = re.compile(unit_type[1:])
+                    type_match = lambda t: r_type.search(t)
+                else:
+                    type_match = lambda t: t == unit_type
 
-        # If we pass name, check if we do regex search or strict search
-        if name:
-            # Check if we do strict search or search by regex:
-            if name[0] == "?":
-                r_name = re.compile(name[1:])
-                name_match = lambda n: r_name.search(n)
-            else:
-                name_match = lambda n: n == name
+            # If we pass name, check if we do regex search or strict search
+            if name:
+                # Check if we do strict search or search by regex:
+                if name[0] == "?":
+                    r_name = re.compile(name[1:])
+                    name_match = lambda n: r_name.search(n)
+                else:
+                    name_match = lambda n: n == name
 
-        try:
-            # If we pass unit_type and name
-            if unit_type and name:
-                result = [
-                    data["unit"]
-                    for node, data in self.G.nodes.data()
-                    if name_match(data["unit"].name)
-                    and type_match(data["unit"].unit_type)
-                ]
+            try:
+                # If we pass unit_type and name
+                if unit_type and name:
+                    result = [
+                        data["unit"]
+                        for node, data in self.G.nodes.data()
+                        if name_match(data["unit"].name)
+                        and type_match(data["unit"].unit_type)
+                    ]
 
-            elif name:
-                result = [
-                    data["unit"]
-                    for node, data in self.G.nodes.data()
-                    if name_match(data["unit"].name)
-                ]
+                elif name:
+                    result = [
+                        data["unit"]
+                        for node, data in self.G.nodes.data()
+                        if name_match(data["unit"].name)
+                    ]
 
-            elif unit_type:
-                result = [
-                    data["unit"]
-                    for node, data in self.G.nodes.data()
-                    if type_match(data["unit"].unit_type)
-                ]
+                elif unit_type:
+                    result = [
+                        data["unit"]
+                        for node, data in self.G.nodes.data()
+                        if type_match(data["unit"].unit_type)
+                    ]
 
-            return result
+                out = result
 
-        except:
-            return []
+            except:
+                out = []
+
+        if exclude_shared:
+            out = exclude_shared_units_from_list(out)
+
+        return out
 
     def qu(self, *args, **kwargs) -> Union[BaseBuildingUnit, List[BaseBuildingUnit]]:
         """
@@ -291,6 +316,7 @@ class Building(object):
                 "heatPumps",
                 "indoorClimate",
                 "custom",
+                "localWeatherStations",
             ]
 
             for unit_type in unit_types:
@@ -328,7 +354,7 @@ class Building(object):
             res += z_i.get_sub_zones(zone_ids=zone_ids)
         return res
 
-    def get_zone(self, id) -> Zone:
+    def get_zone(self, id: int) -> Zone:
         """
 
         :param id:
@@ -344,6 +370,70 @@ class Building(object):
             raise Exception(f"Too many zones found for id (id={id} / {n_zs} found)")
         return zs[0]
 
+    def describe(self, display: bool = True) -> str:
+        apartments = self.characteristics.get("apartments")
+        out = """ID: {id}
+Address: {address}
+City: {city}
+Country: {country}
+
+Type: {building_type}
+Heated area: {area}
+{apartments}
+
+Units:
+==============================\n""".format(
+            id=self.location_id,
+            address=self.location.get("address"),
+            city=self.location.get("city"),
+            country=self.location.get("country"),
+            building_type=self.characteristics.get("type"),
+            area=self.characteristics.get("area"),
+            apartments=(
+                "Apartments: {}".format(apartments) if apartments is not None else ""
+            ),
+        )
+
+        main_was_found = False
+
+        for i in [
+            "main",
+            "heating",
+            "hotWater",
+            "indoorClimate",
+            "electricity",
+            "cooling",
+            "custom",
+            "heatPumps",
+            "weatherStations",
+        ]:
+            units_i = self.query_units(i)
+            if len(units_i) == 0:
+                continue
+            elif i == "main":
+                main_was_found = True
+            elif main_was_found and i in ["heating", "hotWater"]:
+                continue  # Skip heating and hot water, as they are already listed under the main
+
+            out += "    [{}] \n".format(i.upper())
+            for u in units_i:
+                out += u.describe(display=False, prefix="\t -", children=True) + "\n"
+            out += "\n"
+
+        out += """
+Zones:
+==========================\n"""
+        zones = self.zones
+        if len(zones) == 0:
+            out += "(None)\n"
+        else:
+            for z in zones:
+                out += z.describe(prefix="- ", children=True, display=False) + "\n"
+
+        if display:
+            print(out)
+        return out
+
 
 def available_buildings() -> pd.DataFrame:
     """
