@@ -20,12 +20,14 @@ class ControlUnit(BaseBuildingUnit):
     def request_schedule(self, schedule_df) -> Response:
         if self.active is False:
             Logging().warning(
-                """Warning: you are trying to control an unit that is not activated 
-                (id={} / details: [unit: {} / building: [{}] {}])""".format(
-                    self.id,
-                    self.name,
-                    self.building.location["locationId"],
-                    self.building.location["address"],
+                RuntimeWarning(
+                    """Warning: you are trying to control an unit that is not activated 
+                    (id={} / details: [unit: {} / building: [{}] {}])""".format(
+                        self.id,
+                        self.name,
+                        self.building.location["locationId"],
+                        self.building.location["address"],
+                    )
                 )
             )
         if schedule_df["value"].isnull().any():
