@@ -1,4 +1,4 @@
-from datetime import date, datetime, timedelta
+from datetime import date, datetime, timedelta, timezone
 from typing import Union
 
 import dateutil.parser
@@ -6,6 +6,8 @@ from dateutil.tz import tzutc
 
 from preheat_open import TIMEZONE
 
+utc = timezone.utc
+
 
 def timestep_start(step, t):
 
@@ -59,6 +61,7 @@ def datetime_convert(param):
         dt = param
     elif isinstance(param, str):
         dt = dateutil.parser.parse(param)
+        return dt if dt.tzinfo is not None else dt.replace(tzinfo=TIMEZONE)
     else:
         raise TypeError(f"No conversion from type: {type(param)}")
 
@@ -74,18 +77,18 @@ def sanitise_datetime_input(t: Union[datetime, str]) -> datetime:
     return out.astimezone(tzutc())
 
 
-def time_resolution_aliases(time_resolution):
-    if time_resolution in ["minute", "5min"]:
+def time_resolution_aliases(resolution):
+    if resolution in ["minute", "5min"]:
         return "5T"
-    elif time_resolution == "hour":
+    elif resolution == "hour":
         return "H"
-    elif time_resolution == "day":
+    elif resolution == "day":
         return "D"
-    elif time_resolution == "week":
+    elif resolution == "week":
         return "W"
-    elif time_resolution == "month":
+    elif resolution == "month":
         return "MS"
-    elif time_resolution == "year":
+    elif resolution == "year":
         return "YS"
     else:
         return None
