@@ -10,8 +10,12 @@ LOG_FORMAT = "%(asctime)-23s  %(levelname)-8s  %(name)-32s  %(message)-160s  .(%
 
 
 class Logging(metaclass=Singleton):
-    def __init__(self, stack_level: int = 0):
-        self.stack_level = 2 + stack_level
+    def __init__(self, stacklevel: int = 0):
+
+        # Ensure the routing of warnings to the logger when using the logger
+        logging.captureWarnings(True)
+
+        self.get_root_logger = logging.getLogger
         if sys.gettrace() is None:
             logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
         else:
@@ -19,53 +23,69 @@ class Logging(metaclass=Singleton):
 
     def _get_logger(self, failsafe: bool = True, stack_level: int = 0):
         try:
-            frame = inspect.stack()[self.stack_level + stack_level]
+            frame = inspect.stack()[2 + stack_level]
             mod = inspect.getmodule(frame[0])
-            # return logging.getLogger(mod.__package__)
-            return logging.getLogger(mod.__name__.split('.')[-1])
+            # return self.get_root_logger(mod.__package__)
+            return self.get_root_logger().getChild(mod.__name__.split(".")[-1])
         except Exception as e:
             if failsafe is True:
                 warnings.warn(
                     "There was an issue in accessing the desired logger - defaulting to a failsafe one"
                 )
-                return logging.getLogger("Failsafe-log (preheat_open)")
+                return self.get_root_logger().getChild("Failsafe-log (preheat_open)")
             else:
                 raise e
 
+    def set_root_logger(self, func):
+        self.get_root_logger = func
+
     def set_level(self, level: Union[str, int]) -> None:
         logging.basicConfig(level=level, force=True)
 
-    def error(self, msg: str, exception: Optional[Exception], *args, **kwargs) -> None:
+    def error(
+        self,
+        msg: str,
+        exception: Optional[Exception] = None,
+        stack_level: int = 0,
+        *args,
+        **kwargs,
+    ) -> None:
         if exception is None:
-            for line in msg.split("\n"):
-                self._get_logger().error(
-                    line, stacklevel=self.stack_level, *args, **kwargs
+            for line in str(msg).split("\n"):
+                self._get_logger(stack_level=stack_level).error(
+                    line, stacklevel=2 + stack_level, *args, **kwargs
                 )
         else:
             try:
                 raise exception
             except Exception as e:
-                for line in msg.split("\n"):
-                    self._get_logger().exception(
-                        line, stacklevel=self.stack_level, *args, **kwargs
+                for line in str(msg).split("\n"):
+                    self._get_logger(stack_level=stack_level).exception(
+                        line, stacklevel=2 + stack_level, *args, **kwargs
                     )
 
-    def warning(self, msg: Union[str, Warning], *args, **kwargs) -> None:
-        warnings.warn(msg)
+    def warning(
+        self, msg: Union[str, Warning], stack_level: int = 0, *args, **kwargs
+    ) -> None:
         if isinstance(msg, Warning):
-            msg = str(msg)
-        for line in msg.split("\n"):
-            self._get_logger().warning(
-                line, stacklevel=self.stack_level, *args, **kwargs
+            warnings.warn(msg)
+        else:
+            for line in str(msg).split("\n"):
+                self._get_logger(stack_level=stack_level).warning(
+                    line, stacklevel=2 + stack_level, *args, **kwargs
+                )
+
+    def info(self, msg: str, stack_level: int = 0, *args, **kwargs) -> None:
+        for line in str(msg).split("\n"):
+            self._get_logger(stack_level=stack_level).info(
+                line, stacklevel=2 + stack_level, *args, **kwargs
             )
 
-    def info(self, msg: str, *args, **kwargs) -> None:
-        for line in msg.split("\n"):
-            self._get_logger().info(line, stacklevel=self.stack_level, *args, **kwargs)
-
-    def debug(self, msg: str, *args, **kwargs) -> None:
-        for line in msg.split("\n"):
-            self._get_logger().debug(line, stacklevel=self.stack_level, *args, **kwargs)
+    def debug(self, msg: str, stack_level: int = 0, *args, **kwargs) -> None:
+        for line in str(msg).split("\n"):
+            self._get_logger(stack_level=stack_level).debug(
+                line, stacklevel=2 + stack_level, *args, **kwargs
+            )
 
 
 def logging_level(level: str) -> int:
