@@ -9,6 +9,7 @@ from preheat_open import running_in_test_mode
 # Setting up a test API key, which is only valid for a dummy test installation
 API_KEY = "KVkIdWLKac5XFLCs2loKb7GUitkTL4uJXoSyUFIZkVgWuCk8Uj"
 ANONYMISED_API_KEY = "3xa0SeGXa4WlkrB68qGR9NoDAzVvGdiG3XAabKu6n7n5qQTDkL"
+TEST_LOCATION_ID = 2756
 
 # Warning the user that this module is not meant to be used for non test-related activities
 if running_in_test_mode() is False:
@@ -21,7 +22,7 @@ unless you are specifically carrying out a test.
     """
     )
 
-SHORT_TEST_PERIOD = ("2021-05-01 00:00", "2021-05-02 00:00", "hour")
+SHORT_TEST_PERIOD = ("2021-05-01T00:00+02:00", "2021-05-02T00:00+02:00", "hour")
 
 
 class PreheatTest:
@@ -37,7 +38,7 @@ class PreheatTest:
 
     @pytest.fixture(scope="session")
     def building_id(self):
-        return 2756
+        return TEST_LOCATION_ID
 
     @pytest.fixture(scope="session")
     def unit_id(self):
@@ -77,14 +78,14 @@ class PreheatTest:
 
     @pytest.fixture(scope="session")
     def short_period(self):
-        start_date = SHORT_TEST_PERIOD[0]
-        end_date = SHORT_TEST_PERIOD[1]
-        time_resolution = "hour"
-        return start_date, end_date, time_resolution
+        start = SHORT_TEST_PERIOD[0]
+        end = SHORT_TEST_PERIOD[1]
+        resolution = "hour"
+        return start, end, resolution
 
     @pytest.fixture(scope="session")
     def medium_period(self):
-        start_date = "2021-05-01 00:00"
-        end_date = "2021-05-07 00:00"
-        time_resolution = "hour"
-        return start_date, end_date, time_resolution
+        start = "2021-05-01T00:00+02:00"
+        end = "2021-05-07T00:00+02:00"
+        resolution = "hour"
+        return start, end, resolution
