@@ -35,3 +35,17 @@ class TestBuilding(test.PreheatTest):
         zone_A = zone_A1b.get_parent_zone()
         assert zone_A.get_parent_zone() is None
         assert len(zone_A.get_units("indoorClimate")) > 0
+
+    def test_get_unit_types(self, building_with_data):
+        # Zone A1 -- connected to unit named 'indoor_climate_1'
+        zone_A1 = building_with_data.get_zones(zone_ids=[4830])[0]
+        types_A1 = zone_A1.get_unit_types()
+        assert isinstance(types_A1, list)
+        for t in types_A1:
+            assert isinstance(t, str)
+
+        # Zone A2 -- not connected to any units
+        zone_A2 = building_with_data.get_zones(zone_ids=[4831])[0]
+        types_A2 = zone_A2.get_unit_types()
+        assert isinstance(types_A2, list)
+        assert not types_A2
