@@ -4,9 +4,11 @@ from typing import Dict, List, Optional, Union
 import pandas as pd
 
 from .api import TIMEZONE
+from .backwards_compatibility import load_parameter_old_naming
 from .component import Component
 from .data import load_model_data
 from .helpers import (
+    list_to_string,
     now,
     sanitise_datetime_input,
     time_resolution_aliases,
@@ -37,6 +39,9 @@ class Unit(object):
         self.id = unit_data.pop("id", None)
         # Name of the unit
         self.name: str = unit_data.pop("name", "{}_{}".format(self.unit_type, self.id))
+        if not self.name:
+            # If the name does not exist, create one out of the ID and the unit type
+            self.name = "{}_{}".format(self.unit_type, self.id)
 
         # List of components in the unit (PreHEAT_API.Component)
         self.components: List[Component] = self.__populate_components(unit_data)
@@ -69,28 +74,31 @@ class Unit(object):
 
     def load_data(
         self,
-        start_date,
-        end_date,
-        time_resolution: str = "minute",
+        start,
+        end,
+        resolution: str = "minute",
         components: Union[List, None] = None,
         **kwargs,
     ) -> None:
+        start, end, resolution = load_parameter_old_naming(
+            start, end, resolution, **kwargs
+        )
         self._warn_if_data_is_loaded()
         self.data = load_model_data(
             self.get_all_component_ids(components=components),
-            start_date,
-            end_date,
-            time_resolution,
+            start,
+            end,
+            resolution,
         )
-        self._ensure_continuity_of_data(time_resolution)
+        self._ensure_continuity_of_data(resolution)
 
-    def _ensure_continuity_of_data(self, time_resolution: str) -> None:
-        if self.data.empty or (time_resolution == "raw"):
+    def _ensure_continuity_of_data(self, resolution: str) -> None:
+        if self.data.empty or (resolution == "raw"):
             return
 
-        time_alias = time_resolution_aliases(time_resolution)
+        time_alias = time_resolution_aliases(resolution)
 
-        if time_resolution in ["day", "week", "month", "year"]:
+        if resolution in ["day", "week", "month", "year"]:
             # Reindexing to local time prior to frequency conversion
             self.data.index = self.data.index.tz_convert(TIMEZONE)
             self.data = self.data.asfreq(freq=time_alias)
@@ -225,3 +233,15 @@ class Unit(object):
             raise Exception(f"Invalid value for estimate ({estimate})")
 
         return state
+
+    def describe(
+        self, display: bool = True, prefix: str = "", components: bool = True, **kwargs
+    ) -> str:
+        out = prefix + "[{}] {} [id={} / sub-type={}]".format(
+            self.unit_type, self.name, self.id, self.unit_subtype
+        )
+        if components:
+            out += ": " + list_to_string([c.name for c in self.components])
+        if display:
+            print(out)
+        return out
